@@ -22,10 +22,7 @@ def test_simple(redis_conn: StrictRedis, redis_monitor):
 
     assert len(queue) == 20
     items = ','.join(queue.pop() for _ in range(10))
-    assert items in [
-        'a0,b0,a1,b1,a2,b2,a3,b3,a4,b4',
-        'b0,a0,b1,a1,b2,a2,b3,a3,b4,a4',
-    ]
+    assert items == 'a0,b0,a1,b1,a2,b2,a3,b3,a4,b4'
     assert len(queue) == 10
     assert queue.pop() is None
     assert len(queue) == 10
@@ -33,10 +30,29 @@ def test_simple(redis_conn: StrictRedis, redis_monitor):
     sleep(1)
 
     items = ','.join(queue.pop() for _ in range(10))
-    assert items in [
-        'a5,b5,a6,b6,a7,b7,a8,b8,a9,b9',
-        'b5,a5,b6,a6,b7,a7,b8,a8,b9,a9',
-    ]
+    assert items == 'a5,b5,a6,b6,a7,b7,a8,b8,a9,b9'
+    assert queue.pop() is None
+    assert len(queue) == 0
+
+
+def test_priority(redis_conn: StrictRedis, redis_monitor):
+    queue = ThrottledQueue(redis_conn, "test", limit=5, resolution=Resolution.SECOND)
+    for pos, item in enumerate(range(10)):
+        queue.push('aaaaaa', f'a{item}', priority=10 - pos)
+    for pos, item in enumerate(range(10)):
+        queue.push('bbbbbb', f'b{item}', priority=pos)
+
+    assert len(queue) == 20
+    items = ','.join(queue.pop() for _ in range(10))
+    assert items == 'a0,b9,a1,b8,a2,b7,a3,b6,a4,b5'
+    assert len(queue) == 10
+    assert queue.pop() is None
+    assert len(queue) == 10
+
+    sleep(1)
+
+    items = ','.join(queue.pop() for _ in range(10))
+    assert items == 'a5,b4,a6,b3,a7,b2,a8,b1,a9,b0'
     assert queue.pop() is None
     assert len(queue) == 0
 
@@ -49,7 +65,7 @@ def test_extras(redis_conn: StrictRedis, redis_monitor):
         queue.push('bbbbbb', f'b{item}', priority=10 - pos)
 
     assert len(queue) == 20
-    assert queue.pop() in ['a0', 'b0']
+    assert queue.pop() == 'a0'
     assert len(queue) == 19
     queue.push('cccccc', 'c0', priority=11)
     queue.push('cccccc', 'c1', priority=-1)
